@@ -1,3 +1,24 @@
+/*
+ * NIMBLE: an R package for programming with BUGS models.
+ * Copyright (C) 2014-2017 Perry de Valpine, Christopher Paciorek,
+ * Daniel Turek, Clifford Anderson-Bergman, Nick Michaud, Fritz Obermeyer,
+ * Duncan Temple Lang.
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, a copy is available at
+ * https://www.R-project.org/Licenses/
+ */
+
 #include <iostream> // must go before other things because R defines a "length" macro
 #include "nimble/dists.h"
 #include "nimble/nimDists.h"
@@ -403,3 +424,95 @@ void nimArr_rcar_normal(NimArr<1, double> &ans, NimArr<1, double> &adj, NimArr<1
 }
 
 
+double nimArr_dcar_proper(NimArr<1, double> &x, NimArr<1, double> &mu, NimArr<1, double> &C, NimArr<1, double> &adj, NimArr<1, double> &num, NimArr<1, double> &M, double tau, double gamma, NimArr<1, double> &evs, int give_log) {
+  
+  //return give_log ? ML_POSINF: R_D__0;
+  
+  double *xptr, *muptr, *Cptr, *adjptr, *numptr, *Mptr, *evsptr;
+  NimArr<1, double> xCopy, muCopy, CCopy, adjCopy, numCopy, MCopy, evsCopy;
+  
+  xptr = nimArrCopyIfNeeded<1, double>(x, xCopy).getPtr();
+  muptr = nimArrCopyIfNeeded<1, double>(mu, muCopy).getPtr();
+  Cptr = nimArrCopyIfNeeded<1, double>(C, CCopy).getPtr();
+  adjptr = nimArrCopyIfNeeded<1, double>(adj, adjCopy).getPtr();
+  numptr = nimArrCopyIfNeeded<1, double>(num, numCopy).getPtr();
+  Mptr = nimArrCopyIfNeeded<1, double>(M, MCopy).getPtr();
+  evsptr = nimArrCopyIfNeeded<1, double>(evs, evsCopy).getPtr();
+  
+  int N = x.size();
+  if(mu.size() != N) {
+    _nimble_global_output<<"Error in nimArr_dcar_proper: x and mu and different sizes.\n";
+    nimble_print_to_R(_nimble_global_output);
+  }
+  if(num.size() != N) {
+    _nimble_global_output<<"Error in nimArr_dcar_proper: x and num and different sizes.\n";
+    nimble_print_to_R(_nimble_global_output);
+  }
+  if(M.size() != N) {
+    _nimble_global_output<<"Error in nimArr_dcar_proper: x and M and different sizes.\n";
+    nimble_print_to_R(_nimble_global_output);
+  }
+  if(evs.size() != N) {
+    _nimble_global_output<<"Error in nimArr_dcar_proper: x and evs and different sizes.\n";
+    nimble_print_to_R(_nimble_global_output);
+  }
+  int L = adj.size();
+  if(C.size() != L) {
+    _nimble_global_output<<"Error in nimArr_dcar_proper: adj and C and different sizes.\n";
+    nimble_print_to_R(_nimble_global_output);
+  }
+
+  double ans = dcar_proper(xptr, muptr, Cptr, adjptr, numptr, Mptr, tau, gamma, evsptr, N, L, give_log);
+  return(ans);
+}
+
+
+void nimArr_rcar_proper(NimArr<1, double> &ans, NimArr<1, double> &mu, NimArr<1, double> &C, NimArr<1, double> &adj, NimArr<1, double> &num, NimArr<1, double> &M, double tau, double gamma, NimArr<1, double> &evs) {
+
+  double *ansptr, *muptr, *Cptr, *adjptr, *numptr, *Mptr, *evsptr;
+  NimArr<1, double> ansCopy, muCopy, CCopy, adjCopy, numCopy, MCopy, evsCopy;
+  
+  int N = num.size();
+  int L = adj.size();
+  
+  if(!ans.isMap()) {
+    ans.setSize(N);
+  } else {
+    if(ans.size() != N) {
+      _nimble_global_output<<"Error in nimArr_rcar_proper: answer size ("<< ans.size() <<") does not match num size ("<<N<<").\n";
+      nimble_print_to_R(_nimble_global_output);
+    }
+  }
+  if(mu.size() != N) {
+    _nimble_global_output<<"Error in nimArr_rcar_proper: mu size ("<< mu.size() <<") does not match num size ("<<N<<").\n";
+    nimble_print_to_R(_nimble_global_output);
+  }
+  if(C.size() != L) {
+    _nimble_global_output<<"Error in nimArr_rcar_proper: C size ("<< C.size() <<") does not match adj size ("<<L<<").\n";
+    nimble_print_to_R(_nimble_global_output);
+  }
+  if(M.size() != N) {
+    _nimble_global_output<<"Error in nimArr_rcar_proper: M size ("<< M.size() <<") does not match num size ("<<N<<").\n";
+    nimble_print_to_R(_nimble_global_output);
+  }
+  if(evs.size() != N) {
+    _nimble_global_output<<"Error in nimArr_rcar_proper: evs size ("<< evs.size() <<") does not match num size ("<<N<<").\n";
+    nimble_print_to_R(_nimble_global_output);
+  }
+  
+  ansptr = nimArrCopyIfNeeded<1, double>(ans, ansCopy).getPtr();
+  muptr = nimArrCopyIfNeeded<1, double>(mu, muCopy).getPtr();
+  Cptr = nimArrCopyIfNeeded<1, double>(C, CCopy).getPtr();
+  adjptr = nimArrCopyIfNeeded<1, double>(adj, adjCopy).getPtr();
+  numptr = nimArrCopyIfNeeded<1, double>(num, numCopy).getPtr();
+  Mptr = nimArrCopyIfNeeded<1, double>(M, MCopy).getPtr();
+  evsptr = nimArrCopyIfNeeded<1, double>(evs, evsCopy).getPtr();
+  
+  rcar_proper(ansptr, muptr, Cptr, adjptr, numptr, Mptr, tau, gamma, evsptr, N, L);
+  
+  if(ans.isMap()) {
+    ans = ansCopy;
+  }
+}
+
+
