@@ -1,3 +1,24 @@
+/*
+ * NIMBLE: an R package for programming with BUGS models.
+ * Copyright (C) 2014-2017 Perry de Valpine, Christopher Paciorek,
+ * Daniel Turek, Clifford Anderson-Bergman, Nick Michaud, Fritz Obermeyer,
+ * Duncan Temple Lang.
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, a copy is available at
+ * https://www.R-project.org/Licenses/
+ */
+
 #ifndef __RCPPUTILS
 #define __RCPPUTILS
 
@@ -52,6 +73,10 @@ SEXP int_2_SEXP(int i);
 bool SEXP_2_bool(SEXP Sn, int i = 0);
 SEXP bool_2_SEXP(bool ind);
 
+void populate_SEXP_2_double_for_copyFromRobject(void *vPtr, SEXP rScalar);
+void populate_SEXP_2_int_for_copyFromRobject(void *vPtr, SEXP rScalar);
+void populate_SEXP_2_bool_for_copyFromRobject(void *vPtr, SEXP rScalar);
+
 extern "C" {
   SEXP populate_SEXP_2_double(SEXP rPtr, SEXP refNum, SEXP rScalar);
   SEXP extract_double_2_SEXP(SEXP rPtr, SEXP refNum);
